#!/usr/bin/env python
"""List the songs in the spotify queue."""

import os
import spotipy
import termcolor

# from rich import print

client_id = os.environ["SPOTIPY_CLIENT_ID"]
client_secret = os.environ["SPOTIPY_CLIENT_SECRET"]


REDIRECT_URI = "http://localhost:8888/callback/"
SCOPE = "user-read-currently-playing"


auth_manager = spotipy.oauth2.SpotifyOAuth(
    client_id=client_id,
    client_secret=client_secret,
    redirect_uri=REDIRECT_URI,
    scope=SCOPE,
)

print(f"token: {auth_manager.get_cached_token()}")

sp = spotipy.Spotify(auth_manager=auth_manager)
track: dict = sp.current_user_playing_track()


def get_playlist_ids(username: str, playlist_id: str):
    """Get tracks ids using the playlist id and username"""
    info: dict = sp.user_playlist_tracks(username, playlist_id)
    items = info["items"]
    while info["next"]:
        info = sp.next(info)
        items.extend(info["items"])
    return [item["track"]["id"] for item in items]


def tracks(user_id, playlist_id):
    """List all tracks"""
    track_ids = get_playlist_ids(user_id, playlist_id)
    for track_id in track_ids:
        track_item: dict = sp.track(track_id)
        track_fullname = track_item["name"] + "-" + track_item["artists"][0]["name"]
        if track_id == track["item"]["id"]:
            termcolor.cprint(track_fullname, attrs=["bold"])
        else:
            print(track_fullname)


my_id: str = sp.me()["id"]
my_playlist: str = track["context"]["uri"]
tracks(my_id, my_playlist)



#!/usr/bin/env python
import os
import sys
import spotipy
import termcolor

duration_s = float(sys.argv[1])
duration_ms = int(duration_s * 1000)

client_id = os.environ["SPOTIPY_CLIENT_ID"]
client_secret = os.environ["SPOTIPY_CLIENT_SECRET"]
cache_path = os.path.join(os.environ["XDG_RUNTIME_DIR"], ".spcache")

redirect_uri = "http://localhost:8888/callback/"
scope = (
    "user-read-playback-position user-read-playback-state user-modify-playback-state"
)

auth_manager = spotipy.oauth2.SpotifyOAuth(
    client_id=client_id,
    client_secret=client_secret,
    redirect_uri=redirect_uri,
    scope=scope,
    cache_path=cache_path,
)

sp = spotipy.Spotify(auth_manager=auth_manager)
track = sp.current_user_playing_track()
token = auth_manager.get_cached_token()
access_token = token["access_token"]

headers = {
    "Authorization": f"Bearer {access_token}",
    "Content-Type": "application/json",
}
BASE_URL = "https://api.spotify.com/v1/"


playback = sp.current_playback()

progress_ms = playback["progress_ms"]
position_ms = progress_ms + duration_ms

sp.seek_track(position_ms)

track = playback["item"]

track_id = track["id"]
image = track["album"]["images"][0]["url"]
name = track["name"]
artists_names = ", ".join(map(lambda a: a["name"], track["artists"]))


if duration_s < 0:
    duration_text = f"﹣{-duration_s}"
else:
    duration_text = f"+{duration_s}"

os.system(f"curl -so /tmp/spimage {image}")

message = f"{duration_text}s {artists_names} - {name}"
cmd = f'notify-send -i /tmp/spimage "{message}" 2> /dev/stdout'
os.system(cmd)

c_message = termcolor.colored(f"{duration_text}s", "yellow")
c_artists_names = termcolor.colored(artists_names, "blue")
c_name = termcolor.colored(name, "green")

colored_message = f"{c_message} {c_artists_names} - {c_name}"
print(colored_message)



#!/usr/bin/env python
import os
import spotipy
from rich import print

import requests
import termcolor

client_id = os.environ["SPOTIPY_CLIENT_ID"]
client_secret = os.environ["SPOTIPY_CLIENT_SECRET"]


redirect_uri = "http://localhost:8888/callback/"
# scope = "user-library-read"
# scope = "user-read-currently-playing"
# scope = "user-modify-playback-state"
scope = "user-read-currently-playing user-modify-playback-state"


auth_manager = spotipy.oauth2.SpotifyOAuth(
    client_id=client_id,
    client_secret=client_secret,
    redirect_uri=redirect_uri,
    scope=scope,
)

sp = spotipy.Spotify(auth_manager=auth_manager)

track = sp.current_user_playing_track()

token = auth_manager.get_cached_token()
access_token = token["access_token"]
# print(track)
# print(track["context"]["uri"])


# print(sp.track(track_id=track["id"]))
# print(sp.me())


def get_playlist_ids(username, playlist_id):
    r = sp.user_playlist_tracks(username, playlist_id)
    t = r["items"]
    ids = []
    while r["next"]:
        r = sp.next(r)
        t.extend(r["items"])
    for s in t:
        ids.append(s["track"]["id"])
    return ids


def tracks():
    track_ids = get_playlist_ids(sp.me()["id"], track["context"]["uri"])
    for track_id in track_ids:
        track = sp.track(track_id)
        print(track["name"], "-", track["artists"][0]["name"])


headers = {
    "Authorization": f"Bearer {access_token}",
    "Content-Type": "application/json",
}
BASE_URL = "https://api.spotify.com/v1/"


def post(path: str, json: dict = {}) -> requests.Response:
    url = os.path.join(BASE_URL, path)
    return requests.post(url=url, headers=headers, json=json)


def put(path: str, json: dict = {}) -> requests.Response:
    url = os.path.join(BASE_URL, path)
    return requests.put(url=url, headers=headers, json=json)


def next_track():
    response = post("me/player/next")
    print(response.text)


def playpause_song():
    response = put("me/player/pause")
    print(response.reason)
    print(response.text)


def play_song():
    response = put("me/player/play")
    print(response.reason)
    print(response.text)


# current_user_saved_tracks_add(tracks=None)

# playpause_song()
play_song()

# playlists = sp.user_playlists("spotify")
# while playlists:
#     for i, playlist in enumerate(playlists["items"]):
#         print(
#             "%4d %s %s"
#             % (i + 1 + playlists["offset"], playlist["uri"], playlist["name"])
#         )
#     if playlists["next"]:
#         playlists = sp.next(playlists)
#     else:
#         playlists = None

# results = sp.current_user_saved_tracks()
# for idx, item in enumerate(results["items"]):
#     track = item["track"]
#     print(idx, track["artists"][0]["name"], " – ", track["name"])



#!/usr/bin/env python
import os
import spotipy
from rich import print

import requests
import termcolor

client_id = os.environ["SPOTIPY_CLIENT_ID"]
client_secret = os.environ["SPOTIPY_CLIENT_SECRET"]


redirect_uri = "http://localhost:8888/callback/"
scope = "user-read-currently-playing"


auth_manager = spotipy.oauth2.SpotifyOAuth(
    client_id=client_id,
    client_secret=client_secret,
    redirect_uri=redirect_uri,
    scope=scope,
)

sp = spotipy.Spotify(auth_manager=auth_manager)

track = sp.current_user_playing_track()

token = auth_manager.get_cached_token()
access_token = token["access_token"]
# print(track)
# print(track["context"]["uri"])


# print(sp.track(track_id=track["id"]))
print(sp.me())



#!/usr/bin/env python
import os
import spotipy
from rich import print

import termcolor

client_id = os.environ["SPOTIPY_CLIENT_ID"]
client_secret = os.environ["SPOTIPY_CLIENT_SECRET"]
cache_path = os.path.join(os.environ["XDG_RUNTIME_DIR"], ".spcache")

redirect_uri = "http://localhost:8888/callback/"
scope = "user-read-currently-playing user-library-modify"


auth_manager = spotipy.oauth2.SpotifyOAuth(
    client_id=client_id,
    client_secret=client_secret,
    redirect_uri=redirect_uri,
    scope=scope,
    cache_path=cache_path,
)

sp = spotipy.Spotify(auth_manager=auth_manager)
track = sp.current_user_playing_track()
token = auth_manager.get_cached_token()
access_token = token["access_token"]

headers = {
    "Authorization": f"Bearer {access_token}",
    "Content-Type": "application/json",
}
BASE_URL = "https://api.spotify.com/v1/"


track = sp.currently_playing()["item"]

track_id = track["id"]
image = track["album"]["images"][0]["url"]
name = track["name"]
artists_names = ", ".join(map(lambda a: a["name"], track["artists"]))

sp.current_user_saved_tracks_add(tracks=[track_id])

os.system(f"curl -so /tmp/spimage {image}")
message = f"👍 {artists_names} - {name}"
cmd = f'notify-send -i /tmp/spimage "{message}"'
print(message)
os.system(cmd)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['clitify']

package_data = \
{'': ['*']}

install_requires = \
['rich>=12.4.4,<13.0.0', 'spotipy>=2.19.0,<3.0.0', 'termcolors>=0.1.0,<0.2.0']

setup_kwargs = {
    'name': 'clitify',
    'version': '0.1.3',
    'description': 'CLI for the Spotify API using Spotipy',
    'long_description': '# Install\n```sh\npip install clitify\n```\n\n# Source\n![https://cdn-icons-png.flaticon.com/512/25/25231.png]([github.com/marcpartensky/clitify](https://github.com/marcpartensky/clitify))\n',
    'author': 'Marc Partensky',
    'author_email': 'marc.partensky@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/marcpartensky/clitify',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
